// For licensing, see: http://hydrogen.knownspace.org/license.html

/**
 * AndEntityConstraint.java
 */
package org.datamanager.constraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;

/**
 * AndEntityConstraint matches all entities that match both
 * of the EntityConstraints given to it in its constructor.
 *
 * @author Matthew Farrellee
 */
public class AndEntityConstraint
    extends AbstractEntityConstraint
    {
    /**
     * The EntityConstraints to use in the And.
     */
    private EntityConstraint pEntity;
    /**
     * The EntityConstraints to use in the And.
     */
    private EntityConstraint qEntity;

    /**
     * Create a new AndEntityConstraint to work on Entitys
     *
     * @param p An EntityConstraint.
     * @param q An EntityConstraint.
     */
    public AndEntityConstraint(EntityConstraint p, EntityConstraint q)
        {
        this.pEntity = p;
        this.qEntity = q;
        }

    /**
     * Check to see if the given Entity is valid or not.
     *
     * @param defendant An Entity to check.
     *
     * @return Whether the Entity was valid or not.
     */
    protected boolean describes(Entity defendant)
                         throws DataManagerException
        {
        return (pEntity.accepts(defendant) && qEntity.accepts(defendant));
        }
    }