// For licensing, see: http://hydrogen.knownspace.org/license.html

/**
 * AttributeExistsConstraint.java
 * 
 * Author: Benjamin Keil
 * Modified:
 *    Made it extend AbstractEntityConstraint.
 *     -- Matt
 *    Ran it through JIndent, and added javadoc.
 *     -- Matt 26 Dec 1999
 * 
 * Created 199911051504
 */
package org.datamanager.constraint;

import org.datamanager.constraint.EntityConstraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;

import org.datamanager.tools.Debug;

/**
 * Filter out Entities that have an attribute which satisifies
 * a given EntityConstraint.
 * 
 * @author Benjamin Keil
 */
public class AttributeExistsConstraint
    extends AbstractEntityConstraint
    {
    /**
     * The EntityConstraint used to find a valid attribute.
     */
    private EntityConstraint attributeConstraint;

    /**
     * Create a new AttributeExistsConstraint to match all
     * Entities that have an attribute matching the given
     * EntityConstraint.
     *
     * @param attributeConstraint Constraint to use to match
     *                            bases.
     */
    public AttributeExistsConstraint(EntityConstraint attributeConstraint)
        {
        this.attributeConstraint = attributeConstraint;
        }

    /**
     * Check to see if the given Entity has an attribute
     * that satisfies the constraint given in the
     * constructor of this constraint.
     *
     * @param defendant An Entity to check.
     *
     * @return Whether the Entity has an attribute
     *         that satisfies the constraint given
     *         in the constructor of this constriant.
     */
    protected boolean describes(Entity defendant)
                         throws DataManagerException
        {
        Entity[] attributes = defendant.getAttributes(EntityConstraint.NONE);
        boolean doesMatch = false;
        int index = 0;

        while ((index < attributes.length) && (doesMatch != true))
            {
            doesMatch = attributeConstraint.accepts(attributes[index++]);
            }

        return doesMatch;
        }
    }