// For licensing, see: http://hydrogen.knownspace.org/license.html

/**
 * NoneEntityConstraint.java
 *
 * Author: Matthew Farrellee
 */
package org.datamanager.constraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;

/**
 * This EntityConstraint always returns true.
 *
 * @author Matthew Farrellee
 */
class NoneEntityConstraint
    implements EntityConstraint
    {
    /**
     * The only instance of the NoneEntityConstraint.
     */
    private static NoneEntityConstraint instance = new NoneEntityConstraint();

    /**
     * Create a new NoneEntityConstraint
     */
    private NoneEntityConstraint()
        {
        }

    /**
     * Always return true.
     *
     * @param defendant An Entity.
     *
     * @return Always true.
     */
    public boolean accepts(Entity defendant)
                    throws DataManagerException
        {
        return true;
        }

    /**
     * Get an instance of a NoneEntityConstraint.
     *
     * @return A NoneEntityConstraint.
     */
    public static NoneEntityConstraint getInstance()
        {
        return instance;
        }
    }