// For licensing, see: http://hydrogen.knownspace.org/license.html

/**
 * NoneEventConstraint.java
 *
 * Author: Matthew Farrellee
 */
package org.datamanager.constraint;

import org.datamanager.event.DataManagerEvent;

import org.datamanager.exception.DataManagerException;

/**
 * This EventConstraint always returns true.
 *
 * @author Matthew Farrellee
 */
class NoneEventConstraint
    implements EventConstraint
    {
    /**
     * The only instance of the NoneEventConstraint.
     */
    private static NoneEventConstraint instance = new NoneEventConstraint();

    /**
     * Create a new NoneEventConstraint
     */
    private NoneEventConstraint()
        {
        }

    /**
     * Always return true.
     *
     * @param defendant An event.
     *
     * @return Always true.
     */
    public boolean accepts(DataManagerEvent defendant)
                    throws DataManagerException
        {
        return true;
        }

    /**
     * Get an instance of a NoneEventConstraint.
     *
     * @return A NoneEventConstraint.
     */
    public static NoneEventConstraint getInstance()
        {
        return instance;
        }
    }