// For licensing, see: http://hydrogen.knownspace.org/license.html
package org.datamanager.event;

import org.datamanager.event.CollectorEvent;
import org.datamanager.event.DataManagerEventAdapter;

import org.datamanager.kernel.EventGenerator;

/**
Author: gregory j. e. rawlins
Date  : December 7, 1999
**/
/**
Objects of this class encapsulate a collection of parameters determining a
network connection to a remote machine holding a mailbox for a particular user.
The parameters are: username, password, email host machine, email access
protocol (imap, pop3, smtp), and mailbox.
**/
public class EmailParametersEnteredCollectorEvent
    extends DataManagerEventAdapter
    implements CollectorEvent
    {
    private String username;
    private String password;
    private String hostMachineName;
    private String accessProtocolName;
    private String mailboxName;

    /**
    Initialize this event with its generator's reference.
    **/
    public EmailParametersEnteredCollectorEvent(EventGenerator source, 
                                                String username, 
                                                String password, 
                                                String hostMachineName, 
                                                String accessProtocolName, 
                                                String mailboxName)
        {
        super(source);
        this.username = username;
        this.password = password;
        this.hostMachineName = hostMachineName;
        this.accessProtocolName = accessProtocolName;
        this.mailboxName = mailboxName;
        }

    /**
    Report the username
    **/
    public String getUsername()
        {
        return username;
        }

    /**
    Report the password
    **/
    public String getPassword()
        {
        return password;
        }

    /**
    Report the email host machine
    **/
    public String getHostMachineName()
        {
        return hostMachineName;
        }

    /**
    Report the email access protocol
    **/
    public String getAccessProtocolName()
        {
        return accessProtocolName;
        }

    /**
    Report the mailbox
    **/
    public String getMailboxName()
        {
        return mailboxName;
        }

    /**
    Report a string representation of the event
    **/
    public String toString()
        {
        return username + "," + password + "," + hostMachineName + "," + 
               accessProtocolName + "," + mailboxName;
        }
    }