/**
 * $Id: Persistable.java,v 1.4 2002/10/14 06:56:59 alllee Exp $
 *
 *
 * Created: Sat Oct 12 21:49:42 2002
 *
 * @author 
 * @version $Revision: 1.4 $
 *
 * Persistable interface that all future persistable objects might be
 * interested in implementing.  
 */
package org.datamanager.kernel;

import java.io.File;
import java.io.InputStream;
import java.io.OutputStream;

import org.datamanager.persistence.DataAccessObject;
import org.datamanager.persistence.DataAccessObjectFactory;

public interface Persistable
    {
    /** Folder in which persisted objects are placed. */
    static final String PERSISTENCE_FOLDER = "persisted";
    /** Persistence layer factory */
    static final DataAccessObjectFactory PERSISTENCE_FACTORY = 
            DataAccessObjectFactory.newInstance();
    /** 
     * Persistence layer persister object.  Currently using XML-styled
     * persistence.  
     */
    static final DataAccessObject PERSISTER = PERSISTENCE_FACTORY.getDataAccessObject(
                                                      DataAccessObjectFactory.SERIALIZABLE_PERSISTENCE);

    /** 
     * Persists this persistable object to the location specified by File. 
     * 
     * @param File Writes this object to the specified File
     */
    void persist(File location);

    /** 
     * Persists this persistable object to the given OutputStream
     *
     * @param OutputStream Writes this to the given OutputStream
     */
    void persist(OutputStream outputStream);
    } // Persistable
