// For licensing, see: http://hydrogen.knownspace.org/license.html
package org.datamanager.persistence.xml.fieldtypes;

import java.lang.reflect.Field;

import org.datamanager.persistence.xml.XMLDataAccessObject;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.Text;

/**
 * handle char primitive type
 * @author xi rao & Jason Lynn Baumgartner
 */
public class CharFieldType
    implements FieldType
    {
    protected CharFieldType()
        {
        }

    /**
     * retore the state of array of an object from xml file
     * @param field represent the object's field
     * @param object represent the instance of any type of object
     * @param arrayNode XML element for reading state
     */
    public void restorePrimitiveArray(Field field, Object object, 
                                      Node arrayNode)
        {
        try
            {
            NodeList nodeList = arrayNode.getChildNodes();
            int[] intArray = new int[nodeList.getLength()];
            char[] array = new char[nodeList.getLength()];

            for (int i = 0; i < nodeList.getLength(); i++)
                {
                Node node = nodeList.item(i);
                int temp = Integer.parseInt(node.getLastChild().getNodeValue());

                //System.out.println("length:" + nodeList.getLength() + "decode int" + temp);
                //array[i] = (char)node.getLastChild().getNodeValue().toCharArray()[0];
                array[i] = (char) temp;
                }

            field.set(object, array);
            }
        catch (IllegalAccessException iae)
            {
            }
        }

    /**
      * save the state of array of an object to xml file
      * @param field represent the object's field
      * @param object represent the instance of any type of object
      * @param parent the parent xml element for saveing state
     */
    public void persistPrimitiveArray(Field field, Object object, 
                                      Element parent)
        {
        try
            {
            Document ownerDocument = parent.getOwnerDocument();
            char[] charArray = (char[]) field.get(object);

            //int[] intArray = new int[charArray.length];
            for (int i = 0; i < charArray.length; i++)
                {
                Element intElement = ownerDocument.createElement(
                                             XMLDataAccessObject.CHAR);
                int temp = charArray[i];
                System.out.println("encode char-->int:" + temp + ":");

                //Text value = ownerDocument.createTextNode(String.valueOf(
                //                                                  charArray[i]));
                Text value = ownerDocument.createTextNode(String.valueOf(temp));
                intElement.appendChild(value);
                parent.appendChild(intElement);
                }
            }
        catch (IllegalAccessException iae)
            {
            }
        }

    /**
     * restore the state of primitive of an object from xml file
     * @param field field represent the object's filed
     * @param object represent the instance of any type of object
     * @param node xml element for reading state
     */
    public void setPrimitiveValue(Field field, Object object, Node node)
        {
        try
            {
            field.setChar(object, node.getNodeValue().toCharArray()[0]);
            }
        catch (IllegalAccessException iae)
            {
            }
        }
    }