// For licensing, see: http://hydrogen.knownspace.org/license.html
package org.datamanager.persistence.xml.fieldtypes;

import java.util.Hashtable;

import org.datamanager.persistence.xml.XMLDataAccessObject;

/**
 * A simple fixed content table translate the type to correspond object type.
 * It is also responsible for getting a dummy object(wrapper) by input the correspond primitive type or string
 * @author xi rao & Jason Lynn Baumgartner
 */
public class TypeMap
    {
    private Hashtable fieldTypeTable;
    private Hashtable dummyObjectTable;

    /**
     * Constructor: build a dictionary for translation.
     */
    public TypeMap()
        {
        fieldTypeTable = new Hashtable();
        fieldTypeTable.put(XMLDataAccessObject.STRING, new StringFieldType());
        fieldTypeTable.put(XMLDataAccessObject.NULL, new NullFieldType());
        fieldTypeTable.put(XMLDataAccessObject.BOOLEAN, new BooleanFieldType());
        fieldTypeTable.put(XMLDataAccessObject.BYTE, new ByteFieldType());
        fieldTypeTable.put(XMLDataAccessObject.CHAR, new CharFieldType());
        fieldTypeTable.put(XMLDataAccessObject.SHORT, new ShortFieldType());
        fieldTypeTable.put(XMLDataAccessObject.INT, new IntFieldType());
        fieldTypeTable.put(XMLDataAccessObject.LONG, new LongFieldType());
        fieldTypeTable.put(XMLDataAccessObject.FLOAT, new FloatFieldType());
        fieldTypeTable.put(XMLDataAccessObject.DOUBLE, new DoubleFieldType());

        //FixMe(10/11/2002): we don't deal with array situation. We need to deal with it sometimes.
        dummyObjectTable = new Hashtable();
        dummyObjectTable.put(XMLDataAccessObject.STRING_PACKAGE, "dummy value ");
        dummyObjectTable.put(XMLDataAccessObject.BOOLEAN, new Boolean(true));
        dummyObjectTable.put(XMLDataAccessObject.BYTE, new Byte("1"));
        dummyObjectTable.put(XMLDataAccessObject.CHAR, new Character('1'));
        dummyObjectTable.put(XMLDataAccessObject.SHORT, new Short("1"));
        dummyObjectTable.put(XMLDataAccessObject.INT, new Integer(1));
        dummyObjectTable.put(XMLDataAccessObject.LONG, new Long(3));
        dummyObjectTable.put(XMLDataAccessObject.FLOAT, new Float(0.0));
        dummyObjectTable.put(XMLDataAccessObject.DOUBLE, new Double(0.0));
        }

    /**
     * check if it contain the type
     * @param typeKey a string to represent a type
     * @return true if the type is in the table.
     */
    public boolean containsField(String typeKey)
        {
        return fieldTypeTable.containsKey(typeKey);
        }

    /**
     * get the Object type for primitives.
     * @param typeKey a string to represent a type
     * @return the object type for primitives.
     */
    public FieldType getFieldType(String typeKey)
        {
        if (!containsField(typeKey))
            {
            typeKey = XMLDataAccessObject.NULL;
            }

        return (FieldType) fieldTypeTable.get(typeKey);
        }

    /**
     * check if it containt the type
     * @param typeKey a string to represent a type
     * @return true if the type is in the table
     */
    public boolean containsDummyObject(String typeKey)
        {
        return dummyObjectTable.containsKey(typeKey);
        }

    /**
     * get the dummy object for pass into constructor.
     * @param typeKey a string to represent a type
     * @return  the dummy wrapper primitive object
     */
    public Object getDummyObject(String typeKey)
        {
        if (!containsDummyObject(typeKey))
            {
            return null;
            }

        return dummyObjectTable.get(typeKey);
        }
    }