///////////////////////////////////////////////////////////////////////////////
// 2002-10-13 mml
// Created so that we can examine persistence.
///////////////////////////////////////////////////////////////////////////////
package org.datamanager.kernel;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import java.lang.InterruptedException;
import java.lang.Thread;

import java.util.Vector;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.WindowConstants;

import org.datamanager.constraint.EntityConstraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Simpleton;

import org.datamanager.passiveentityvalue.StringEntityValue;

/**
 * A Simpleton to examine persistence.
 *
 * @author Matt Liggett
 */
public class EntityMakerSimpleton
    extends Simpleton
    {
    /** A display list of all Entities we know about. */
    private JList entityList;
    /** A button to make a new Entity. */
    private JButton makeEntityButton;
    /** This Simpleton's toplevel graphical element. */
    private JFrame frame;

    /**
     * Displays the GUI, then loops forever querying the Kernel for a list of
     * Entities and updating the JList with that list.
     */
    public void process()
        {
        makeFrame();
        frame.pack();
        frame.setVisible(true);

        try
            {
            while (frame.isShowing())
                {
                Entity[] entityArray = Pool.getDefaultPool()
                                           .search(EntityConstraint.NONE);
                entityList.setListData(entityArray);
                Thread.currentThread().sleep(1000);
                }
            }
        catch (DataManagerException exception)
            {
            exception.printStackTrace();
            }
        catch (InterruptedException exception)
            {
            exception.printStackTrace();
            }
        }

    /**
     * Adds a meaningless Entity to the pool.
     */
    private void createEntity()
        {
        try
            {
            Entity entity = Entity.create("abracadabra");
            entity.setValue(new StringEntityValue("frizzuit"));
            Pool.getDefaultPool().add(entity);
            }
        catch (DataManagerException exception)
            {
            exception.printStackTrace();
            }
        }

    /**
     * Creates the JFrame and other components that go in it; configures
     * layout.
     */
    private void makeFrame()
        {
        frame = new JFrame(getInformation().getName());
        frame.setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);

        entityList = new JList();
        frame.getContentPane().add(entityList, BorderLayout.CENTER);

        makeEntityButton = new JButton("Make Entity");
        makeEntityButton.addActionListener(new ActionListener()
            {
            public void actionPerformed(ActionEvent event)
                {
                createEntity();
                }
            });

        frame.getContentPane().add(makeEntityButton, BorderLayout.SOUTH);

        frame.getContentPane().add(new JLabel("Entities"), BorderLayout.NORTH);
        }
    }